@@ -30,6 +30,8 @@ typedef struct cal_entry {
     struct cal_entry *next;
     char const *text;
     char const *pos;
+    int is_color;
+    int r, g, b;
     int time;
     int priority;
     char tag[TAG_LEN+1];
@@ -39,15 +41,88 @@ typedef struct cal_entry {
     int lineno;
 } CalEntry;
 
+/* Line-drawing sequences */
+struct line_drawing {
+  char const *graphics_on;
+  char const *graphics_off;
+  char tlr, bl, tbl, blr, tblr, tr, tb, br, tbr, tl, lr;
+};
+
+static struct line_drawing NormalDrawing = {
+  "", "", '+', '+', '+', '+', '+', '+', '|', '+', '+', '+', '-'
+};
+
+static struct line_drawing VT100Drawing = {
+  "\x1B(0", "\x1B(B",
+  '\x76', '\x6b', '\x75', '\x77', '\x6e', '\x6d', '\x78',
+  '\x6c', '\x74', '\x6a', '\x71'
+};
+
+static char *VT100Colors[2][2][2][2] /* [Br][R][G][B] */ = {
+  {
+  /*** DIM COLORS ***/
+    {
+      {
+	/* 0, 0, 0 = Black   */ "\x1B[0;30m",
+	/* 0, 0, 1 = Blue    */ "\x1B[0;34m"
+      },
+      {
+	/* 0, 1, 0 = Green   */ "\x1B[0;32m",
+	/* 0, 1, 1 = Cyan    */ "\x1B[0;36m"
+      }
+    },
+    {
+      {
+	/* 1, 0, 0 = Red     */ "\x1B[0;31m",
+	/* 1, 0, 1 = Magenta */ "\x1B[0;35m"
+      },
+      {
+	/* 1, 1, 0 = Yellow  */ "\x1B[0;33m",
+	/* 1, 1, 1 = White   */ "\x1B[0;37m"
+      }
+    }
+  },
+  {
+  /*** BRIGHT COLORS ***/
+    {
+      {
+	/* 0, 0, 0 = Grey    */ "\x1B[30;1m",
+	/* 0, 0, 1 = Blue    */ "\x1B[34;1m"
+      },
+      {
+	/* 0, 1, 0 = Green   */ "\x1B[32;1m",
+	/* 0, 1, 1 = Cyan    */ "\x1B[36;1m"
+      }
+    },
+    {
+      {
+	/* 1, 0, 0 = Red     */ "\x1B[31;1m",
+	/* 1, 0, 1 = Magenta */ "\x1B[35;1m"
+      },
+      {
+	/* 1, 1, 0 = Yellow  */ "\x1B[33;1m",
+	/* 1, 1, 1 = White   */ "\x1B[37;1m"
+      }
+    }
+  }
+};
+
+static struct line_drawing *linestruct;
+#define DRAW(x) putchar(linestruct->x)
+
 /* Global variables */
 static CalEntry *CalColumn[7];
 
 static int ColSpaces;
 
+static void Colorize(CalEntry const *e);
+static void Decolorize(void);
 static void SortCol (CalEntry **col);
-static void DoCalendarOneWeek (void);
+static void DoCalendarOneWeek (int nleft);
 static void DoCalendarOneMonth (void);
 static int WriteCalendarRow (void);
+static void WriteWeekHeaderLine (void);
+static void WritePostHeaderLine (void);
 static void PrintLeft (char const *s, int width, char pad);
 static void PrintCentered (char const *s, int width, char pad);
 static int WriteOneCalLine (void);
@@ -57,10 +132,42 @@ static void WriteCalHeader (void);
 static void WriteCalTrailer (void);
 static int DoCalRem (ParsePtr p, int col);
 static void WriteSimpleEntries (int col, int jul);
-static void WriteSolidCalLine (void);
+static void WriteTopCalLine (void);
+static void WriteBottomCalLine (void);
 static void WriteIntermediateCalLine (void);
 static void WriteCalDays (void);
 
+static void gon(void)
+{
+  printf("%s", linestruct->graphics_on);
+}
+static void goff(void)
+{
+  printf("%s", linestruct->graphics_off);
+}
+
+static void Decolorize(void)
+{
+  printf("%s", "\x1B[0m");
+}
+
+static void Colorize(CalEntry const *e)
+{
+  int bright = 0;
+  int r, g, b;
+  if (e->r > 128 || e->g > 128 || e->b > 128) {
+    bright = 1;
+  }
+  if (e->r > 64) r = 1;
+  else r = 0;
+  if (e->g > 64) g = 1;
+  else g = 0;
+  if (e->b > 64) b = 1;
+  else b = 0;
+
+  printf("%s", VT100Colors[bright][r][g][b]);
+}
+
 /***************************************************************/
 /*                                                             */
 /*  ProduceCalendar                                            */
@@ -72,6 +179,11 @@ void ProduceCalendar(void)
 {
     int y, m, d;
 
+    if (UseVTChars) {
+        linestruct = &VT100Drawing;
+    } else {
+        linestruct = &NormalDrawing;
+    }
     ShouldCache = 1;
 
     ColSpaces = (CalWidth - 9) / 7;
@@ -88,13 +200,13 @@ void ProduceCalendar(void)
 	else             JulianToday -= ((JulianToday+1)%7);
 
 	if (!DoSimpleCalendar) {
-	    WriteIntermediateCalLine();
+  	    WriteWeekHeaderLine();
 	    WriteCalDays();
 	    WriteIntermediateCalLine();
 	}
 
 	while (CalWeeks--)
-	    DoCalendarOneWeek();
+	    DoCalendarOneWeek(CalWeeks);
 	return;
     }
 }
@@ -106,7 +218,7 @@ void ProduceCalendar(void)
 /*  Write a calendar for a single week                         */
 /*                                                             */
 /***************************************************************/
-static void DoCalendarOneWeek(void)
+static void DoCalendarOneWeek(nleft)
 {
     int y, m, d, done, i, l, wd;
     char buf[81];
@@ -132,7 +244,9 @@ static void DoCalendarOneWeek(void)
     }
 
 /* Here come the first few lines... */
-    PutChar('|');
+    gon();
+    DRAW(tb);
+    goff();
     for (i=0; i<7; i++) {
 	FromJulian(OrigJul+i, &y, &m, &d);
 	sprintf(buf, "%d %c%c%c ", d, MonthName[m][0], MonthName[m][1],
@@ -141,14 +255,20 @@ static void DoCalendarOneWeek(void)
 	    PrintLeft(buf, ColSpaces, '*');
 	else
 	    PrintLeft(buf, ColSpaces, ' ');
-	PutChar('|');
+	gon();
+	DRAW(tb);
+	goff();
     }
     PutChar('\n');
     for (l=0; l<CalPad; l++) {
-	PutChar('|');
+	gon();
+	DRAW(tb);
+	goff();
 	for (i=0; i<7; i++) {
 	    PrintLeft("", ColSpaces, ' ');
-	    PutChar('|');
+	    gon();
+	    DRAW(tb);
+	    goff();
 	}
 	PutChar('\n');
     }
@@ -162,16 +282,24 @@ static void DoCalendarOneWeek(void)
 
 /* Write any blank lines required */
     while (LinesWritten++ < CalLines) {
-	PutChar('|');
+        gon();
+        DRAW(tb);
+        goff();
 	for (i=0; i<7; i++) {
 	    PrintLeft("", ColSpaces, ' ');
-	    PutChar('|');
+	    gon();
+	    DRAW(tb);
+	    goff();
 	}
 	PutChar('\n');
     }
 
 /* Write the final line */
-    WriteIntermediateCalLine();
+    if (nleft) {
+        WriteIntermediateCalLine();
+    } else {
+        WriteBottomCalLine();
+    }
 }
 
 /***************************************************************/
@@ -228,6 +356,7 @@ static int WriteCalendarRow(void)
     char buf[81];
     int OrigJul = JulianToday;
     int LinesWritten = 0;
+    int moreleft;
 
 /* Get the date of the first day */
     FromJulian(JulianToday, &y, &m, &d);
@@ -253,7 +382,9 @@ static int WriteCalendarRow(void)
 
 
 /* Here come the first few lines... */
-    PutChar('|');
+    gon();
+    DRAW(tb);
+    goff();
     for (i=0; i<7; i++) {
 	if (i < wd || d+i-wd>DaysInMonth(m, y))
 	    PrintLeft("", ColSpaces, ' ');
@@ -261,14 +392,20 @@ static int WriteCalendarRow(void)
 	    sprintf(buf, "%d", d+i-wd);
 	    PrintLeft(buf, ColSpaces, ' ');
 	}
-	PutChar('|');
+	gon();
+	DRAW(tb);
+	goff();
     }
     PutChar('\n');
     for (l=0; l<CalPad; l++) {
-	PutChar('|');
+        gon();
+	DRAW(tb);
+	goff();
 	for (i=0; i<7; i++) {
 	    PrintLeft("", ColSpaces, ' ');
-	    PutChar('|');
+	    gon();
+	    DRAW(tb);
+	    goff();
 	}
 	PutChar('\n');
     }
@@ -282,18 +419,27 @@ static int WriteCalendarRow(void)
 
 /* Write any blank lines required */
     while (LinesWritten++ < CalLines) {
-	PutChar('|');
+        gon();
+	DRAW(tb);
+	goff();
 	for (i=0; i<7; i++) {
 	    PrintLeft("", ColSpaces, ' ');
-	    PutChar('|');
+	    gon();
+	    DRAW(tb);
+	    goff();
 	}
 	PutChar('\n');
     }
 
-    WriteIntermediateCalLine();
+    moreleft = (d+7-wd <= DaysInMonth(m, y));
+    if (moreleft) {
+        WriteIntermediateCalLine();
+    } else {
+        WriteBottomCalLine();
+    }
 
 /* Return non-zero if we have not yet finished */
-    return (d+7-wd <= DaysInMonth(m, y));
+    return moreleft;
 }
 
 /***************************************************************/
@@ -341,14 +487,18 @@ static int WriteOneCalLine(void)
 {
     int done = 1, i;
 
-    PutChar('|');
+    gon();
+    DRAW(tb);
+    goff();
     for (i=0; i<7; i++) {
 	if (CalColumn[i]) {
 	    if (WriteOneColLine(i)) done = 0;
 	} else {
 	    PrintCentered("", ColSpaces, ' ');
 	}
-	PutChar('|');
+	gon();
+	DRAW(tb);
+	goff();
     }
     PutChar('\n');
 
@@ -393,6 +543,11 @@ static int WriteOneColLine(int col)
 	s++;
     }
 
+/* Colorize reminder if necessary */
+    if (UseVTColors && e->is_color) {
+        Colorize(e);
+    }
+
 /* If we couldn't find a space char, print what we have. */
     if (!space) {
 	for (s = e->pos; s - e->pos < ColSpaces; s++) {
@@ -411,6 +566,11 @@ static int WriteOneColLine(int col)
 	}
     }
 
+/* Decolorize reminder if necessary */
+    if (UseVTColors && e->is_color) {
+        Decolorize();
+    }
+
 /* Flesh out the rest of the column */
     while(numwritten++ < ColSpaces) PutChar(' ');
 
@@ -449,7 +609,7 @@ static void GenerateCalEntries(int col)
     DestroyVars(0);
     NumTriggered = 0;
 
-    r=OpenFile(InitialFile);
+    r=IncludeFile(InitialFile);
     if (r) {
 	fprintf(ErrFp, "%s %s: %s\n", ErrMsg[E_ERR_READING], InitialFile, ErrMsg[r]);
 	exit(1);
@@ -549,14 +709,18 @@ static void WriteCalHeader(void)
     FromJulian(JulianToday, &y, &m, &d);
     sprintf(buf, "%s %d", MonthName[m], y);
 
-    WriteSolidCalLine();
+    WriteTopCalLine();
 
-    PutChar('|');
+    gon();
+    DRAW(tb);
+    goff();
     PrintCentered(buf, CalWidth-2, ' ');
-    PutChar('|');
+    gon();
+    DRAW(tb);
+    goff();
     PutChar('\n');
 
-    WriteIntermediateCalLine();
+    WritePostHeaderLine();
     WriteCalDays();
     WriteIntermediateCalLine();
 }
@@ -592,6 +756,9 @@ static int DoCalRem(ParsePtr p, int col)
     DynamicBuffer buf, obuf, pre_buf;
     Token tok;
 
+    int is_color, col_r, col_g, col_b;
+
+    is_color = 0;
     DBufInit(&buf);
     DBufInit(&pre_buf);
 
@@ -604,6 +771,7 @@ static int DoCalRem(ParsePtr p, int col)
     if (trig.typ == SAT_TYPE) {
 	r=DoSatRemind(&trig, &tim, p);
 	if (r) return r;
+	if (!LastTrigValid) return OK;
 	r=ParseToken(p, &buf);
 	if (r) return r;
 	FindToken(DBufValue(&buf), &tok);
@@ -640,6 +808,7 @@ static int DoCalRem(ParsePtr p, int col)
     if (trig.typ == PASSTHRU_TYPE) {
       if (!PsCal && strcmp(trig.passthru, "COLOR")) return OK;
       if (!strcmp(trig.passthru, "COLOR")) {
+  	  is_color = 1;
 	  /* Strip off the three color numbers */
 	  DBufFree(&buf);
 	  r=ParseToken(p, &buf);
@@ -657,6 +826,15 @@ static int DoCalRem(ParsePtr p, int col)
 	  DBufPutc(&pre_buf, ' ');
 	  DBufFree(&buf);
 	  if (r) return r;
+	  (void) sscanf(DBufValue(&pre_buf), "%d %d %d",
+			&col_r, &col_g, &col_b);
+	  if (col_r < 0) col_r = 0;
+	  else if (col_r > 255) col_r = 255;
+	  if (col_g < 0) col_g = 0;
+	  else if (col_g > 255) col_g = 255;
+	  if (col_b < 0) col_b = 0;
+	  else if (col_b > 255) col_b = 255;
+
 	  if (!PsCal && !DoSimpleCalendar) {
 	      DBufFree(&pre_buf);
 	  }
@@ -666,8 +844,7 @@ static int DoCalRem(ParsePtr p, int col)
     /* If trigger date == today, add it to the current entry */
     DBufInit(&obuf);
     if ((jul == JulianToday) ||
-	(DoSimpleCalendar &&
-	 DoSimpleCalDelta &&
+	(DoSimpleCalDelta &&
 	 ShouldTriggerReminder(&trig, &tim, jul))) {
 	NumTriggered++;
 
@@ -749,6 +926,10 @@ static int DoCalRem(ParsePtr p, int col)
 	DBufPuts(&pre_buf, s);
 	s = DBufValue(&pre_buf);
 	e = NEW(CalEntry);
+	e->is_color = is_color;
+	e->r = col_r;
+	e->g = col_g;
+	e->b = col_b;
 	if (!e) {
 	    DBufFree(&obuf);
 	    DBufFree(&pre_buf);
@@ -844,11 +1025,64 @@ static void WriteSimpleEntries(int col, int jul)
 /*  Various functions for writing different types of lines.    */
 /*                                                             */
 /***************************************************************/
-static void WriteSolidCalLine(void)
+static void WriteTopCalLine(void)
 {
-    PutChar('+');
-    PrintCentered("", CalWidth-2, '-');
-    PutChar('+');
+    gon();
+    DRAW(br);
+    PrintCentered("", CalWidth-2, linestruct->lr);
+    DRAW(bl);
+    goff();
+    PutChar('\n');
+}
+
+static void WriteBottomCalLine(void)
+{
+    int i;
+    gon();
+    DRAW(tr);
+    for (i=0; i<7; i++) {
+	PrintCentered("", ColSpaces, linestruct->lr);
+	if (i != 6) {
+	    DRAW(tlr);
+	} else {
+	    DRAW(tl);
+	}
+    }
+    goff();
+    PutChar('\n');
+}
+
+static void WritePostHeaderLine(void)
+{
+    int i;
+    gon();
+    DRAW(tbr);
+    for (i=0; i<7; i++) {
+	PrintCentered("", ColSpaces, linestruct->lr);
+	if (i != 6) {
+	    DRAW(blr);
+	} else {
+	    DRAW(tbl);
+	}
+    }
+    goff();
+    PutChar('\n');
+}
+
+static void WriteWeekHeaderLine(void)
+{
+    int i;
+    gon();
+    DRAW(br);
+    for (i=0; i<7; i++) {
+	PrintCentered("", ColSpaces, linestruct->lr);
+	if (i != 6) {
+	    DRAW(blr);
+	} else {
+	    DRAW(bl);
+	}
+    }
+    goff();
     PutChar('\n');
 }
 
@@ -856,24 +1090,34 @@ static void WriteIntermediateCalLine(void)
 {
     int i;
 
-    PutChar('+');
+    gon();
+    DRAW(tbr);
     for (i=0; i<7; i++) {
-	PrintCentered("", ColSpaces, '-');
-	PutChar('+');
+	PrintCentered("", ColSpaces, linestruct->lr);
+	if (i != 6) {
+	    DRAW(tblr);
+	} else {
+	    DRAW(tbl);
+	}
     }
+    goff();
     PutChar('\n');
 }
 
 static void WriteCalDays(void)
 {
     int i;
-    PutChar('|');
+    gon();
+    DRAW(tb);
+    goff();
     for (i=0; i<7; i++) {
 	if (!MondayFirst)
 	    PrintCentered(DayName[(i+6)%7], ColSpaces, ' ');
 	else
 	    PrintCentered(DayName[i%7], ColSpaces, ' ');
-	PutChar('|');
+	gon();
+	DRAW(tb);
+	goff();
     }
     PutChar('\n');
 }
