@@ -30,6 +30,10 @@
 #include <stdlib.h>
 #include <unistd.h>
 
+#ifdef HAVE_GLOB_H
+#include <glob.h>
+#endif
+
 #include "types.h"
 #include "protos.h"
 #include "globals.h"
@@ -53,9 +57,23 @@ typedef struct cheader {
     int ownedByMe;
 } CachedFile;
 
+/* A linked list of filenames if we INCLUDE /some/directory/  */
+typedef struct fname_chain {
+    struct fname_chain *next;
+    char const *filename;
+} FilenameChain;
+
+/* Cache filename chains for directories */
+typedef struct directory_fname_chain {
+    struct directory_fname_chain *next;
+    FilenameChain *chain;
+    char const *dirname;
+} DirectoryFilenameChain;
+
 /* Define the structures needed by the INCLUDE file system */
 typedef struct {
     char const *filename;
+    FilenameChain *chain;
     int LineNo;
     unsigned int IfFlags;
     int NumIfs;
@@ -66,6 +84,7 @@ typedef struct {
 
 static CachedFile *CachedFiles = (CachedFile *) NULL;
 static CachedLine *CLine = (CachedLine *) NULL;
+static DirectoryFilenameChain *CachedDirectoryChains = NULL;
 
 static FILE *fp;
 
@@ -76,6 +95,23 @@ static int ReadLineFromFile (void);
 static int CacheFile (char const *fname);
 static void DestroyCache (CachedFile *cf);
 static int CheckSafety (void);
+static int PopFile (void);
+
+static void FreeChainItem(FilenameChain *chain)
+{
+	if (chain->filename) free((void *) chain->filename);
+	free(chain);
+}
+
+static void FreeChain(FilenameChain *chain)
+{
+    FilenameChain *next;
+    while(chain) {
+	next = chain->next;
+	FreeChainItem(chain);
+	chain = next;
+    }
+}
 
 /***************************************************************/
 /*                                                             */
@@ -140,7 +176,7 @@ static int ReadLineFromFile(void)
 	}
 	l = DBufLen(&buf);
 	if (l && (DBufValue(&buf)[l-1] == '\\')) {
-	    DBufValue(&buf)[l-1] = 0;
+	    DBufValue(&buf)[l-1] = '\n';
 	    if (DBufPuts(&LineBuffer, DBufValue(&buf)) != OK) {
 		DBufFree(&buf);
 		DBufFree(&LineBuffer);
@@ -183,6 +219,9 @@ int OpenFile(char const *fname)
 
     while (h) {
 	if (!strcmp(fname, h->filename)) {
+	    if (DebugFlag & DB_TRACE_FILES) {
+		fprintf(ErrFp, "Reading `%s': Found in cache\n", fname);
+	    }
 	    CLine = h->cache;
 	    STRSET(FileName, fname);
 	    LineNo = 0;
@@ -197,8 +236,14 @@ int OpenFile(char const *fname)
 /* If it's a dash, then it's stdin */
     if (!strcmp(fname, "-")) {
 	fp = stdin;
+	if (DebugFlag & DB_TRACE_FILES) {
+	    fprintf(ErrFp, "Reading `-': Reading stdin\n");
+	}
     } else {
 	fp = fopen(fname, "r");
+	if (DebugFlag & DB_TRACE_FILES) {
+	    fprintf(ErrFp, "Reading `%s': Opening file on disk\n", fname);
+	}
     }
     if (!fp || !CheckSafety()) return E_CANT_OPEN;
     CLine = NULL;
@@ -237,6 +282,9 @@ static int CacheFile(char const *fname)
     CachedLine *cl;
     char const *s;
 
+    if (DebugFlag & DB_TRACE_FILES) {
+	fprintf(ErrFp, "Caching file `%s' in memory\n", fname);
+    }
     cl = NULL;
 /* Create a file header */
     cf = NEW(CachedFile);
@@ -311,13 +359,33 @@ static int CacheFile(char const *fname)
     return OK;
 }
 
+/***************************************************************/
+/*                                                             */
+/*  NextChainedFile - move to the next chained file in a glob  */
+/*  list.                                                      */
+/*                                                             */
+/***************************************************************/
+static int NextChainedFile(IncludeStruct *i)
+{
+    while(i->chain) {
+	FilenameChain *cur = i->chain;
+	i->chain = i->chain->next;
+	if (OpenFile(cur->filename) == OK) {
+	    return OK;
+	} else {
+	    Eprint("%s: %s", ErrMsg[E_CANT_OPEN], cur->filename);
+	}
+    }
+    return E_EOF;
+}
+
 /***************************************************************/
 /*                                                             */
 /*  PopFile - we've reached the end.  Pop up to the previous   */
 /*  file, or return E_EOF                                      */
 /*                                                             */
 /***************************************************************/
-int PopFile(void)
+static int PopFile(void)
 {
     IncludeStruct *i;
 
@@ -326,8 +394,21 @@ int PopFile(void)
 
     if (!Hush && NumIfs) Eprint("%s", ErrMsg[E_MISS_ENDIF]);
     if (!IStackPtr) return E_EOF;
+    i = &IStack[IStackPtr-1];
+
+    if (i->chain) {
+	int oldRunDisabled = RunDisabled;
+	if (NextChainedFile(i) == OK) {
+	    return OK;
+	}
+	RunDisabled = oldRunDisabled;
+    }
+
+    if (IStackPtr <= 1) {
+	return E_EOF;
+    }
+
     IStackPtr--;
-    i = &IStack[IStackPtr];
 
     LineNo = i->LineNo;
     IfFlags = i->IfFlags;
@@ -361,13 +442,13 @@ int PopFile(void)
 /*                                                             */
 /***************************************************************/
 int DoInclude(ParsePtr p)
-{     
+{
     DynamicBuffer buf;
     int r, e;
 
     DBufInit(&buf);
     if ( (r=ParseToken(p, &buf)) ) return r;
-    e = VerifyEoln(p); 
+    e = VerifyEoln(p);
     if (e) Eprint("%s", ErrMsg[e]);
     if ( (r=IncludeFile(DBufValue(&buf))) ) {
 	DBufFree(&buf);
@@ -379,6 +460,114 @@ int DoInclude(ParsePtr p)
     return OK;
 }
 
+#ifdef HAVE_GLOB
+static int SetupGlobChain(char const *dirname, IncludeStruct *i)
+{
+    DynamicBuffer pattern;
+    char *dir;
+    size_t l;
+    int r;
+    glob_t glob_buf;
+    DirectoryFilenameChain *dc = CachedDirectoryChains;
+
+    i->chain = NULL;
+    if (!*dirname) return E_CANT_OPEN;
+
+    dir = StrDup(dirname);
+    if (!dir) return E_NO_MEM;
+
+    /* Strip trailing slashes off directory */
+    l = strlen(dir);
+    while(l) {
+	if (*(dir+l-1) == '/') {
+	    l--;
+	    *(dir+l) = 0;
+	} else {
+	    break;
+	}
+    }
+
+    /* Repair root directory :-) */
+    if (!l) {
+	*dir = '/';
+    }
+
+    /* Check the cache */
+    while(dc) {
+	if (!strcmp(dc->dirname, dir)) {
+	    free(dir);
+	    i->chain = dc->chain;
+	    return OK;
+	}
+	dc = dc->next;
+    }
+
+    if (ShouldCache) {
+	dc = malloc(sizeof(DirectoryFilenameChain));
+	if (dc) {
+	    dc->dirname = StrDup(dir);
+	    if (!dc->dirname) {
+		free(dc);
+		dc = NULL;
+	    }
+	}
+	if (dc) {
+	    dc->chain = NULL;
+	    dc->next = CachedDirectoryChains;
+	    CachedDirectoryChains = dc;
+	}
+    }
+
+    DBufInit(&pattern);
+    DBufPuts(&pattern, dir);
+    DBufPuts(&pattern, "/*.rem");
+    free(dir);
+
+    r = glob(DBufValue(&pattern), 0, NULL, &glob_buf);
+    DBufFree(&pattern);
+
+    if (r == GLOB_NOMATCH) {
+	globfree(&glob_buf);
+	return OK;
+    }
+
+    if (r != 0) {
+	globfree(&glob_buf);
+	return -1;
+    }
+
+    /* Add the files to the chain backwards to preserve sort order */
+    for (r=glob_buf.gl_pathc-1; r>=0; r--) {
+	FilenameChain *ch = malloc(sizeof(FilenameChain));
+	if (!ch) {
+	    globfree(&glob_buf);
+	    FreeChain(i->chain);
+	    i->chain = NULL;
+	    return E_NO_MEM;
+	}
+
+	/* TODO: stat the file and only add if it's a plain file and
+	   readable by us */
+	ch->filename = StrDup(glob_buf.gl_pathv[r]);
+	if (!ch->filename) {
+	    globfree(&glob_buf);
+	    FreeChain(i->chain);
+	    i->chain = NULL;
+	    free(ch);
+	    return E_NO_MEM;
+	}
+	ch->next = i->chain;
+	i->chain = ch;
+    }
+    if (dc) {
+	dc->chain = i->chain;
+    }
+
+    globfree(&glob_buf);
+    return OK;
+}
+#endif
+
 /***************************************************************/
 /*                                                             */
 /*  IncludeFile                                                */
@@ -390,19 +579,25 @@ int DoInclude(ParsePtr p)
 int IncludeFile(char const *fname)
 {
     IncludeStruct *i;
-    int r;
     int oldRunDisabled;
+    struct stat statbuf;
 
+    FreshLine = 1;
     if (IStackPtr+1 >= INCLUDE_NEST) return E_NESTED_INCLUDE;
     i = &IStack[IStackPtr];
 
-    i->filename = StrDup(FileName);
-    if (!i->filename) return E_NO_MEM;
+    if (FileName) {
+	i->filename = StrDup(FileName);
+	if (!i->filename) return E_NO_MEM;
+    } else {
+	i->filename = NULL;
+    }
     i->LineNo = LineNo;
     i->NumIfs = NumIfs;
     i->IfFlags = IfFlags;
     i->CLine = CLine;
     i->offset = -1L;
+    i->chain = NULL;
     if (RunDisabled & RUN_NOTOWNER) {
 	i->ownedByMe = 0;
     } else {
@@ -415,15 +610,55 @@ int IncludeFile(char const *fname)
 
     IStackPtr++;
 
+#ifdef HAVE_GLOB
+    /* If it's a directory, set up the glob chain here. */
+    if (stat(fname, &statbuf) == 0) {
+	FilenameChain *fc;
+	if (S_ISDIR(statbuf.st_mode)) {
+	    if (DebugFlag & DB_TRACE_FILES) {
+		fprintf(ErrFp, "Scanning directory `%s' for *.rem files\n", fname);
+	    }
+	    if (SetupGlobChain(fname, i) == OK) { /* Glob succeeded */
+		if (!i->chain) { /* Oops... no matching files */
+		    if (!Hush) {
+			Eprint("%s: %s", fname, ErrMsg[E_NO_MATCHING_REMS]);
+		    }
+		    PopFile();
+		    return E_NO_MATCHING_REMS;
+		}
+		while(i->chain) {
+		    fc = i->chain;
+		    i->chain = i->chain->next;
+
+		    /* Munch first file */
+		    oldRunDisabled = RunDisabled;
+		    if (!OpenFile(fc->filename)) {
+			return OK;
+		    }
+		    Eprint("%s: %s", ErrMsg[E_CANT_OPEN], fc->filename);
+		    RunDisabled = oldRunDisabled;
+		}
+		/* Couldn't open anything... bail */
+		return PopFile();
+	    } else {
+		if (!Hush) {
+		    Eprint("%s: %s", fname, ErrMsg[E_NO_MATCHING_REMS]);
+		}
+	    }
+	    return E_NO_MATCHING_REMS;
+	}
+    }
+#endif
+
     oldRunDisabled = RunDisabled;
     /* Try to open the new file */
     if (!OpenFile(fname)) {
 	return OK;
     }
     RunDisabled = oldRunDisabled;
-    /* Ugh!  We failed!  */
-    if ( (r=PopFile()) ) return r;
     Eprint("%s: %s", ErrMsg[E_CANT_OPEN], fname);
+    /* Ugh!  We failed!  */
+    PopFile();
     return E_CANT_OPEN;
 }
 
