@@ -53,6 +53,7 @@ EXTERN  INIT(   int     CalMonths, 0);
 EXTERN  INIT(	int 	Hush, 0);
 EXTERN  INIT(	int 	NextMode, 0);
 EXTERN  INIT(	int 	InfiniteDelta, 0);
+EXTERN  INIT(   int     DeltaOffset, 0);
 EXTERN  INIT(   int     RunDisabled, 0);
 EXTERN  INIT(   int     IgnoreOnce, 0);
 EXTERN  INIT(   int     SortByTime, 0);
@@ -89,6 +90,8 @@ EXTERN  int ArgC;
 EXTERN  char const **ArgV;
 EXTERN  INIT(   int     CalLines, CAL_LINES);
 EXTERN  INIT(   int     CalPad, 1);
+EXTERN  INIT(   int     UseVTChars, 0);
+EXTERN  INIT(   int     UseVTColors, 0);
 
 /* Latitude and longitude */
 EXTERN  INIT(	int	  LatDeg, LAT_DEG);
