@@ -52,6 +52,7 @@
  *  -h       = Hush mode
  *  -f       = Do not fork
  *  -dchars  = Debugging mode:  Chars are:
+ *             f = Trace file openings
  *             e = Echo input lines
  *             x = Display expression evaluation
  *             t = Display trigger dates
@@ -130,6 +131,7 @@ void InitRemind(int argc, char const *argv[])
     Token tok;
     int InvokedAsRem = 0;
     char const *s;
+    int weeks;
 
     /* Initialize global dynamic buffers */
     DBufInit(&Banner);
@@ -222,9 +224,15 @@ void InitRemind(int argc, char const *argv[])
 
 	    case 't':
 	    case 'T':
-		InfiniteDelta = 1;
+		if (!*arg) {
+		    InfiniteDelta = 1;
+		} else {
+		    PARSENUM(DeltaOffset, arg);
+		    if (DeltaOffset < 0) {
+			DeltaOffset = 0;
+		    }
+		}
 		break;
-
 	    case 'e':
 	    case 'E':
 		ErrFp = stdout;
@@ -295,8 +303,33 @@ void InitRemind(int argc, char const *argv[])
 	    case 'c':
 	    case 'C':
 		DoCalendar = 1;
-		if (*arg == '+') {
-		    arg++;
+		weeks = 0;
+		/* Parse the flags */
+		while(*arg) {
+		    if (*arg == 'a' ||
+		        *arg == 'A') {
+		        DoSimpleCalDelta = 1;
+			arg++;
+			continue;
+		    }
+		    if (*arg == '+') {
+		        weeks = 1;
+			arg++;
+			continue;
+		    }
+		    if (*arg == 'l' || *arg == 'L') {
+		        UseVTChars = 1;
+			arg++;
+			continue;
+		    }
+		    if (*arg == 'c' || *arg == 'C') {
+		        UseVTColors = 1;
+		        arg++;
+		        continue;
+		    }
+		    break;
+		}
+		if (weeks) {
 		    PARSENUM(CalWeeks, arg);
 		    if (!CalWeeks) CalWeeks = 1;
 		} else {
@@ -308,12 +341,21 @@ void InitRemind(int argc, char const *argv[])
 	    case 's':
 	    case 'S':
 		DoSimpleCalendar = 1;
-		if (*arg == 'a' || *arg == 'A') {
+		weeks = 0;
+		while(*arg) {
+		    if (*arg == 'a' || *arg == 'A') {
 			DoSimpleCalDelta = 1;
 			arg++;
+			continue;
+		    }
+		    if (*arg == '+') {
+		        arg++;
+			weeks = 1;
+			continue;
+		    }
+		    break;
 		}
-		if (*arg == '+') {
-		    arg++;
+		if (weeks) {
 		    PARSENUM(CalWeeks, arg);
 		    if (!CalWeeks) CalWeeks = 1;
 		} else {
@@ -363,11 +405,12 @@ void InitRemind(int argc, char const *argv[])
 	    case 'D':
 		while (*arg) {
 		    switch(*arg++) {
-		    case 'e': case 'E': DebugFlag |= DB_ECHO_LINE; break;
-		    case 'x': case 'X': DebugFlag |= DB_PRTEXPR;   break;
-		    case 't': case 'T': DebugFlag |= DB_PRTTRIG;   break;
-		    case 'v': case 'V': DebugFlag |= DB_DUMP_VARS; break;
-		    case 'l': case 'L': DebugFlag |= DB_PRTLINE;   break;
+		    case 'e': case 'E': DebugFlag |= DB_ECHO_LINE;   break;
+		    case 'x': case 'X': DebugFlag |= DB_PRTEXPR;     break;
+		    case 't': case 'T': DebugFlag |= DB_PRTTRIG;     break;
+		    case 'v': case 'V': DebugFlag |= DB_DUMP_VARS;   break;
+		    case 'l': case 'L': DebugFlag |= DB_PRTLINE;     break;
+		    case 'f': case 'F': DebugFlag |= DB_TRACE_FILES; break;
 		    default:
 		        fprintf(ErrFp, ErrMsg[M_BAD_DB_FLAG], *(arg-1));
 		    }
@@ -506,7 +549,7 @@ void InitRemind(int argc, char const *argv[])
 void Usage(void)
 {
     fprintf(ErrFp, "\nREMIND %s (%s version) Copyright 1992-1998 David F. Skoll\n", VERSION, L_LANGNAME);
-    fprintf(ErrFp, "Copyright 1999-2007 Roaring Penguin Software Inc.\n");
+    fprintf(ErrFp, "Copyright 1999-2008 Roaring Penguin Software Inc.\n");
 #ifdef BETA
     fprintf(ErrFp, ">>>> BETA VERSION <<<<\n");
 #endif
@@ -514,21 +557,21 @@ void Usage(void)
     fprintf(ErrFp, "Options:\n");
     fprintf(ErrFp, " -n     Output next occurrence of reminders in simple format\n");
     fprintf(ErrFp, " -r     Disable RUN directives\n");
-    fprintf(ErrFp, " -c[n]  Produce a calendar for n (default 1) months\n");
-    fprintf(ErrFp, " -c+[n] Produce a calendar for n (default 1) weeks\n");
+    fprintf(ErrFp, " -c[a][n] Produce a calendar for n (default 1) months\n");
+    fprintf(ErrFp, " -c[a]+[n] Produce a calendar for n (default 1) weeks\n");
     fprintf(ErrFp, " -w[n[,p[,s]]]  Specify width, padding and spacing of calendar\n");
     fprintf(ErrFp, " -s[a][+][n] Produce `simple calendar' for n (1) months (weeks)\n");
     fprintf(ErrFp, " -p[a][n] Same as -s, but input compatible with rem2ps\n");
     fprintf(ErrFp, " -l     Prefix each simple calendar line with line number and filename comment\n");
     fprintf(ErrFp, " -v     Verbose mode\n");
     fprintf(ErrFp, " -o     Ignore ONCE directives\n");
-    fprintf(ErrFp, " -t     Trigger all future reminders regardless of delta\n");
+    fprintf(ErrFp, " -t[n]  Trigger all future (or those within `n' days)\n");
     fprintf(ErrFp, " -h     `Hush' mode - be very quiet\n");
     fprintf(ErrFp, " -a     Don't trigger timed reminders immediately - just queue them\n");
     fprintf(ErrFp, " -q     Don't queue timed reminders\n");
     fprintf(ErrFp, " -f     Trigger timed reminders by staying in foreground\n");
     fprintf(ErrFp, " -z[n]  Enter daemon mode, waking every n (5) minutes.\n");
-    fprintf(ErrFp, " -d...  Debug: e=echo x=expr-eval t=trig v=dumpvars l=showline\n");
+    fprintf(ErrFp, " -d...  Debug: e=echo x=expr-eval t=trig v=dumpvars l=showline f=tracefiles\n");
     fprintf(ErrFp, " -e     Divert messages normally sent to stderr to stdout\n");
     fprintf(ErrFp, " -b[n]  Time format for cal: 0=am/pm, 1=24hr, 2=none\n");
     fprintf(ErrFp, " -x[n]  Iteration limit for SATISFY clause (def=150)\n");
@@ -612,6 +655,20 @@ static void ChgUser(char const *user)
 	putenv(logname);
     }
 }
+
+static void
+DefineFunction(char const *str)
+{
+    Parser p;
+    int r;
+
+    CreateParser(str, &p);
+    r = DoFset(&p);
+    DestroyParser(&p);
+    if (r != OK) {
+	fprintf(ErrFp, "-i option: %s: %s\n", str, ErrMsg[r]);
+    }
+}
 /***************************************************************/
 /*                                                             */
 /*  InitializeVar                                              */
@@ -622,7 +679,7 @@ static void ChgUser(char const *user)
 static void InitializeVar(char const *str)
 {
     char const *expr;
-
+    char const *ostr = str;
     char varname[VAR_NAME_LEN+1];
 
     Value val;
@@ -635,6 +692,11 @@ static void InitializeVar(char const *str)
 	if (r < VAR_NAME_LEN) {
 	    varname[r++] = *str;
 	}
+	if (*str == '(') {
+	    /* Do a function definition if we see a paren */
+	    DefineFunction(ostr);
+	    return;
+	}
 	str++;
     }
     varname[r] = 0;
