@@ -148,7 +148,7 @@ static void DoReminders(void)
 	exit(1);
     }
 
-    r=OpenFile(InitialFile);
+    r=IncludeFile(InitialFile);
     if (r) {
 	fprintf(ErrFp, "%s %s: %s\n", ErrMsg[E_ERR_READING],
 		InitialFile, ErrMsg[r]);
@@ -345,6 +345,7 @@ int ParseChar(ParsePtr p, int *err, int peek)
 		return *(p->pos++);
 	    }
 	}
+	p->expr_happened = 1;
 	p->pos++;
 	r = EvalExpr(&(p->pos), &val);
 	if (r) {
@@ -510,14 +511,16 @@ void Eprint(char const *fmt, ...)
     /* Check if more than one error msg. from this line */
     if (!FreshLine && !ShowAllErrors) return;
 
-    if (FreshLine) {
+    if (FreshLine && FileName) {
 	FreshLine = 0;
 	if (strcmp(FileName, "-"))
 	    (void) fprintf(ErrFp, "%s(%d): ", FileName, LineNo);
 	else
 	    (void) fprintf(ErrFp, "-stdin-(%d): ", LineNo);
 	if (DebugFlag & DB_PRTLINE) OutputLine(ErrFp);
-    } else fprintf(ErrFp, "       ");
+    } else if (FileName) {
+	fprintf(ErrFp, "       ");
+    }
 
     va_start(argptr, fmt);
     (void) vfprintf(ErrFp, fmt, argptr);
@@ -563,6 +566,7 @@ void CreateParser(char const *s, ParsePtr p)
     p->etext = NULL;
     p->allownested = 1;
     p->tokenPushed = NULL;
+    p->expr_happened = 0;
     DBufInit(&p->pushedToken);
 }
 
@@ -859,6 +863,11 @@ int DoDebug(ParsePtr p)
 	    else     DebugFlag &= ~DB_PRTLINE;
 	    break;
 
+	case 'f':
+	case 'F':
+	    if (val) DebugFlag |= DB_TRACE_FILES;
+	    else     DebugFlag &= ~DB_TRACE_FILES;
+	    break;
 	}
     }
 }
