@@ -223,6 +223,11 @@ int DoSet (Parser *p)
     r = ParseIdentifier(p, &buf);
     if (r) return r;
 
+    /* Allow option equals-sign:  SET var = value */
+    if (ParseNonSpaceChar(p, &r, 1) == '=') {
+	ParseNonSpaceChar(p, &r, 0);
+    }
+
     r = EvaluateExpr(p, &v);
     if (r) {
 	DBufFree(&buf);
@@ -463,6 +468,7 @@ static SysVar SysVarArr[] = {
     {   "Daemon",	  0,	INT_TYPE,	&Daemon,	0,	0   },
     {   "DateSep",        1,    SPECIAL_TYPE,   date_sep_func,  0,      0   },
     {   "DefaultPrio",	  1,	INT_TYPE,	&DefaultPrio,	0,	9999 },
+    {   "DeltaOffset",    0,    INT_TYPE,       &DeltaOffset,   0,      0   },
     {   "DontFork",	  0,	INT_TYPE,	&DontFork,	0,	0   },
     {   "DontQueue",	  0,	INT_TYPE,	&DontQueue,	0,	0   },
     {   "DontTrigAts",	  0,	INT_TYPE,	&DontIssueAts,	0,	0   },
